{$M 4096,0,0}
{
  DO2LZEXE permits a DOS command to be performed on an LZEXE processed file

  Written by David Gwillim  4 Mar 1990
}

uses
   Dos;

const
   LZEXE_Sig : array[1..4] of char = 'LZ09';

{
Ŀ
 BIOSGetKey 

}
function BIOSGetKey : word;
inline($B4/$00/$CD/$16);

{
Ŀ
 ShowUsage 

}
procedure ShowUsage;
begin
   writeln('   ͻ');
   writeln('     DO2LZEXE v1.0.0 - Utility for LZEXE processed files  ');
   writeln('            Written by David Gwillim  4 March 1990        ');
   writeln('       THIS PROGRAM IS RELEASED INTO THE PUBLIC DOMAIN    ');
   writeln('   ͼ');
   writeln;
   writeln('  USAGE: DO2LZEXE FileSpec [~] [!] [CommandString]');
   writeln('  Where:');
   writeln('       FileSpec is any valid DOS file specification. It can contain wildcards.');
   writeln('       ~        If this is present as the 2nd parameter then the');
   writeln('                commands will be generated for files that HAVE NOT');
   writeln('                been processed by LZEXE.');
   writeln('       !        If this is present as the 2nd or 3rd parameter then');
   writeln('                the commands will be executed rather than written to');
   writeln('                the standard output.');
   writeln('  CommandString is a string containing embedded "&" characters.');
   writeln('                The string may also contain space characters.');
   writeln('                Each occurrence of the & will be replaced with');
   writeln('                each file name that matches the file spec and');
   writeln('                has/has not(~) been processed by LZEXE.');
   writeln;
   writeln('  If no command is specified the file names which match FileSpec and');
   writeln('  have/have not(~) been processed by LZEXE are sent to the standard output.');
   writeln;
   write('Press <Esc> to stop, any other key for examples ...');
   if (BIOSGetKey = $011B) then
      Halt;
   writeln;
   writeln;
   writeln('Examples:');
   writeln;
   writeln('  DO2LZEXE C:\*.EXE');
   writeln('    displays the names of all EXE files in C:\ processed by LZEXE');
   writeln;
   writeln('  DO2LZEXE D:\TMP\*.EXE ~');
   writeln('    displays the names of all EXE files in D:\TMP NOT processed by LZEXE');
   writeln;
   writeln('  DO2LZEXE C:\BIN\*.EXE ! DEL');
   writeln('    will delete all EXE files in C:\BIN processed by LZEXE');
   writeln;
   writeln('  DO2LZEXE F:\*.EXE ! COPY & A:');
   writeln('    will copy all EXE files in F:\ processed by LZEXE to drive A:');
   writeln;
   writeln('  DO2LZEXE *.EXE ~ ! LZEXE');
   writeln('    will use LZEXE to convert all EXE files in the current directory that');
   writeln('    that have not already been converted');
   writeln;
   writeln('  DO2LZEXE *.EXE ~ LZEXE');
   writeln('    will write commands to the standard output that will use');
   writeln('    LZEXE to convert all EXE files in the current directory that');
   writeln('    that have not already been converted');
   Halt(1);
end;

{
Ŀ
 IsLZEXEd 

}
function IsLZEXEd(FileName : PathStr) : boolean;
var
   F: file;
   Sig : longint;
begin
   assign(F,FileName);
   reset(F,1);
   Seek(F,28);
   BlockRead(F,Sig,SizeOf(longint));
   close(F);
   if Sig = longint(LZEXE_Sig) then
      IsLZEXEd := TRUE
   else
      IsLZEXEd := FALSE;
end;

{
Ŀ
 PerformDosCmd 

}
procedure PerformDosCmd(Cmd : string);
var
   Dir : DirStr;
   Name : NameStr;
   Ext : ExtStr;
   CmdProcessor : PathStr;
begin
   CmdProcessor := GetEnv('COMSPEC');
   Exec(CmdProcessor,'/C '+Cmd);
end;

{
Ŀ
 ProcessParms 

}
procedure ProcessParms;
var
   S : SearchRec;
   Dir : DirStr;
   Name : NameStr;
   Ext : ExtStr;
   FileSpec : PathStr;
   FileCount : word;
   DosCmd : string;
   UserCmd : string;
   n : word;
   HandleLZEXEfiles : boolean;
   ExecuteCommand : boolean;
begin
   HandleLZEXEfiles := FALSE;
   ExecuteCommand := FALSE;
   if ParamCount = 0 then
      ShowUsage;
   FileCount := 0;
   n := 2;
   FileSpec := ParamStr(1);
   if ParamStr(n) = '~' then
   begin
      Inc(n);
      HandleLZEXEfiles := TRUE;
   end;
   if ParamStr(n) = '!' then
   begin
      Inc(n);
      ExecuteCommand := TRUE;
   end;
   UserCmd := '';
   for n := n to ParamCount do
      UserCmd := UserCmd + ParamStr(n) + ' ';
   FSplit(FileSpec,Dir,Name,Ext);
   FindFirst(FileSpec,Archive,S);
   while DosError = 0 do
   begin
      FileSpec := Dir+S.Name;
      if IsLZEXEd(FileSpec) xor HandleLZEXEfiles then
      begin
         Inc(FileCount);
         DosCmd := UserCmd;
         if DosCmd <> '' then
         begin
            if Pos('&',DosCmd) = 0 then
               DosCmd := DosCmd + FileSpec
            else
               while Pos('&',DosCmd) <> 0 do
               begin
                  n := Pos('&',DosCmd);
                  Delete(DosCmd,n,1);
                  Insert(FileSpec,DosCmd,n);
               end;
            if ExecuteCommand then
               PerformDosCmd(DosCmd)
            else
               writeln(DosCmd);
         end
         else
            writeln(' ',FileSpec);
      end;
      FindNext(S);
   end;
   writeln;
   if FileCount = 0 then
      write(': No')
   else
      write(': ',FileCount);
   write(' files found that were ');
   if HandleLZEXEfiles then
      write('NOT ');
   writeln('processed by LZEXE v',LZEXE_Sig);
end;

begin
   ProcessParms;
end.
